See also issues tracked for mile-stone web2ldap-1.8

# 1.8.1

Release Date: 2022-11-22

- Cleaned up some HTML templates.
- Corrected links in web page.
- Fixed application entry-point in examples.

# 1.8.0

Release Date: 2022-11-09

## Installation and configuration changes

- Renamed plugin module for dNSDomain/dNSDomain2 schema to web2ldap.app.plugin.dnsdomain. You might have to adjust your plugin import configuration in web2ldapcnf.plugins.

## New features/enhancements

- Registered UCS attribute lockTime with plugin class SecondsSinceEpoch.
- Registered MS AD attribute msRTCSIP-PrimaryUserAddress with plugin class Uri.
- Added new plugin module web2ldap.app.plugins.dnszone (web2ldap#60).

## Bug fixes

- Fixed returning the diagnosticMessage text as error message in case no more information could be extracted from it.
- Fixed plugin class for GUID values in MS AD to use little-endian encoding/decoding.

## Refactoring

- Renamed entry-point sub-module to web2ldap.__main__.
- Abandoned obsolete optimization with `codecs.lookup()` (closes #58).